============
Installation
============

At the command line::

    $ pip install smartystreets.py

This will install the package `smartystreets` into your Python path, along with
`requests <http://docs.python-requests.org/en/latest/>`_ if it is not installed
already, or the previously installed version is < 2.0.

If you want to make use of the async client you will need to install `grequests`
separately. Since this client is optional so too is the dependency.
